@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import logging
-import urlparse
+import urllib.parse
 
 import ldap3
 from ldap3.core.exceptions import LDAPException
@@ -18,19 +18,19 @@ section = 'ldap_authentication'
 
 # Old version of urlparse doesn't parse query for ldap
 # see http://bugs.python.org/issue9374
-if 'ldap' not in urlparse.uses_query:
-    urlparse.uses_query.append('ldap')
+if 'ldap' not in urllib.parse.uses_query:
+    urllib.parse.uses_query.append('ldap')
 
 
 def parse_ldap_url(uri):
-    unquote = urlparse.unquote
+    unquote = urllib.parse.unquote
     uri = parse_uri(uri)
     dn = unquote(uri.path)[1:]
     attributes, scope, filter_, extensions = (
         uri.query.split('?') + [''] * 4)[:4]
     if not scope:
         scope = 'base'
-    extensions = urlparse.parse_qs(extensions)
+    extensions = urllib.parse.parse_qs(extensions)
     return (uri, dn, unquote(attributes), unquote(scope), unquote(filter_),
         extensions)
 
@@ -48,8 +48,7 @@ def ldap_server():
             scheme, uri.hostname, uri.port or port))
 
 
-class User:
-    __metaclass__ = PoolMeta
+class User(metaclass=PoolMeta):
     __name__ = 'res.user'
 
     @classmethod
@@ -132,35 +131,6 @@ class User:
                 cls._check_passwd_ldap_user(logins)
         super(User, cls).write(*args)
 
-    @classmethod
-    def set_preferences(cls, values, parameters):
-        if 'password' in values:
-            if 'password' not in parameters:
-                msg = cls.fields_get(['password'])['password']['string']
-                raise LoginException('password', msg, type='password')
-            old_password = parameters['password']
-            try:
-                server = ldap_server()
-                if server:
-                    user = cls(Transaction().user)
-                    uid = config.get(section, 'uid', default='uid')
-                    users = cls.ldap_search_user(
-                        user.login, server, attrs=[uid])
-                    if users and len(users) == 1:
-                        [(dn, attrs)] = users
-                        con = ldap3.Connection(server, dn, old_password)
-                        if con.bind():
-                            con.extend.standard.modify_password(
-                                dn, old_password, values['password'])
-                            values = values.copy()
-                            del values['password']
-                        else:
-                            cls.raise_user_error('wrong_password')
-            except LDAPException:
-                logger.error('LDAPError when setting preferences',
-                    exc_info=True)
-        super(User, cls).set_preferences(values, parameters)
-
     @classmethod
     def _login_ldap(cls, login, parameters):
         if 'password' not in parameters:
@@ -178,7 +148,7 @@ class User:
                     if (password and con.bind()):
                         # Use ldap uid so we always get the right case
                         login = attrs.get(uid, [login])[0]
-                        user_id, _ = cls._get_login(login)
+                        user_id = cls._get_login(login)[0]
                         if user_id:
                             return user_id
                         elif config.getboolean(section, 'create_user'):
